BreakpointManager

Struct BreakpointManager 

pub struct BreakpointManager { /* private fields */ }
Breakpoint manager

Implementations

Source

impl BreakpointManager

pub fn new() -> Self

Create a new breakpoint manager

pub fn set_breakpoint( &mut self, location: BreakpointLocation, ) -> JitResult<BreakpointId>

Set a breakpoint at the specified location

Arguments
  • location - The location where the breakpoint should be set
Returns

The ID of the newly created breakpoint

Examples
use torsh_jit::debugger::{BreakpointManager, BreakpointLocation};
use torsh_jit::NodeId;

let mut manager = BreakpointManager::new();
let location = BreakpointLocation::GraphNode(NodeId::new(0));
let id = manager.set_breakpoint(location).unwrap();
pub fn set_conditional_breakpoint( &mut self, location: BreakpointLocation, condition: String, ) -> JitResult<BreakpointId>

Set a conditional breakpoint at the specified location

Arguments
  • location - The location where the breakpoint should be set
  • condition - The condition that must be true for the breakpoint to trigger
Returns

The ID of the newly created breakpoint

pub fn remove_breakpoint(&mut self, id: BreakpointId) -> JitResult<()>

Remove a breakpoint by ID

Arguments
  • id - The ID of the breakpoint to remove
Returns

Ok(()) if the breakpoint was removed, error if not found

pub fn enable_breakpoint(&mut self, id: BreakpointId) -> JitResult<()>

Enable a breakpoint

Arguments
  • id - The ID of the breakpoint to enable
pub fn disable_breakpoint(&mut self, id: BreakpointId) -> JitResult<()>

Disable a breakpoint

Arguments
  • id - The ID of the breakpoint to disable
pub fn list_breakpoints(&self) -> Vec<&Breakpoint>

Get a list of all breakpoints

Returns

A vector of references to all breakpoints

pub fn get_breakpoint(&self, id: BreakpointId) -> Option<&Breakpoint>

Get a specific breakpoint by ID

Arguments
  • id - The ID of the breakpoint to retrieve
Returns

An optional reference to the breakpoint

pub fn is_breakpoint_at(&self, location: &ExecutionLocation) -> bool

Check if there is a breakpoint at the specified location

Arguments
  • location - The execution location to check
Returns

true if there is an enabled breakpoint at the location, false otherwise

pub fn hit_breakpoints_at(&mut self, location: &ExecutionLocation) -> usize

Increment hit count for breakpoints at the specified location

Arguments
  • location - The execution location where a hit occurred
Returns

The number of breakpoints hit at this location

pub fn clear_all_breakpoints(&mut self)

Clear all breakpoints

pub fn count(&self) -> usize

Get the number of breakpoints

pub fn enabled_count(&self) -> usize

Get the number of enabled breakpoints

pub fn get_breakpoints_at( &self, location: &BreakpointLocation, ) -> Vec<&Breakpoint>

Get all breakpoints at a specific location

Arguments
  • location - The location to search for breakpoints
Returns

A vector of references to breakpoints at the specified location