pub struct CallStack { /* private fields */ }Expand description
Call stack management
Implementations
Sourceimpl CallStack
impl CallStack
Sourcepub fn with_max_depth(max_depth: usize) -> Self
pub fn with_max_depth(max_depth: usize) -> Self
Create a new call stack with specified maximum depth
Arguments
max_depth- Maximum allowed call stack depth
Sourcepub fn pop(&mut self) -> ExecutionLocation
pub fn pop(&mut self) -> ExecutionLocation
Pop the top frame from the call stack
Returns
The return location from the popped frame, or Completed if stack is empty
Sourcepub fn current_frame(&self) -> Option<&CallFrame>
pub fn current_frame(&self) -> Option<&CallFrame>
Get a reference to the current (top) frame
Sourcepub fn current_frame_mut(&mut self) -> Option<&mut CallFrame>
pub fn current_frame_mut(&mut self) -> Option<&mut CallFrame>
Get a mutable reference to the current (top) frame
Sourcepub fn find_frames_by_function(&self, function_name: &str) -> Vec<usize>
pub fn find_frames_by_function(&self, function_name: &str) -> Vec<usize>
Sourcepub fn get_summary(&self) -> CallStackSummary
pub fn get_summary(&self) -> CallStackSummary
Get a summary of the call stack
Sourcepub fn set_max_depth(&mut self, max_depth: usize)
pub fn set_max_depth(&mut self, max_depth: usize)
Set the maximum depth for the call stack